.. this will be appended to README.rst

Changelog
=========

..

   Feature request
   .................

   Known regressions
   ..................

   Commit items for NEXT VERSION
   ..............................

.. scriv-start-here

.. scriv-end-here
